# gstflow_interface

`gstflow_interface` is a lightweight Python module that allows dynamic interaction with native C/C++ libraries conforming to the [GSTFlow](https://example.com) framework. It provides a seamless interface for image/video processing using user-defined shared libraries.

## Features

- Interact with native C/C++ libraries exposing the `gstflow_custom_process` function
- Automatically handles buffer allocation and deallocation
- Supports image arrays via NumPy
- Easily embeddable in automation pipelines or DeepStream applications

## Requirements

- Python 3.7+
- NumPy
- A compiled shared library that defines:
  - `void gstflow_custom_process(GstflowBuffer* input, GstflowBuffer* output)`
  - `void gstflow_free_buffer(GstflowBuffer* buffer)`

## Usage

```python
import os
from gstflow_interface import gstflow_process_image
import numpy as np

os.environ["GSTFLOW_USER_LIB"] = "/path/to/your/library.so"

image = np.zeros((480, 640, 3), dtype=np.uint8)
output_images = gstflow_process_image(image)

# output_images is a list of numpy arrays
